@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -184,7 +184,7 @@ public class FormatData_am extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
             };
@@ -205,7 +205,7 @@ public class FormatData_am extends ListResourceBundle {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u12d3\u1218\u1275" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "\u1302 \u12a4\u121d \u1272{0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -230,6 +230,7 @@ public class FormatData_am extends ListResourceBundle {
                     "\u12d3\u1218\u1270 \u121d\u1215\u1228\u1275",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -248,6 +249,8 @@ public class FormatData_am extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -258,6 +261,7 @@ public class FormatData_am extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u1325\u12cb\u1275/\u12a8\u1230\u12d3\u1275" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.roc", "\u12e8\u121a\u1295\u1309 \u12e8\u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -265,15 +269,8 @@ public class FormatData_am extends ListResourceBundle {
             { "field.second", "\u1230\u12a8\u1295\u12f5" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "\u12e8\u12a5\u1235\u120b\u121b\u12ca \u12e8\u1230\u12d3\u1275 \u12a0\u1246\u1323\u1320\u122d" },
+            { "calendarname.islamic", "\u12a5\u1235\u120b\u121b\u12ca \u12e8\u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -283,18 +280,18 @@ public class FormatData_am extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u123a",
-                    "00 \u123a",
-                    "000 \u123a",
-                    "0 \u121a\u120a\u12ee\u1295",
-                    "00 \u121a\u120a\u12ee\u1295",
-                    "000 \u121a\u120a\u12ee\u1295",
-                    "0 \u1262\u120a\u12ee\u1295",
-                    "00 \u1262\u120a\u12ee\u1295",
-                    "000 \u1262\u120a\u12ee\u1295",
-                    "0 \u1275\u122a\u120a\u12ee\u1295",
-                    "00 \u1275\u122a\u120a\u12ee\u1295",
-                    "000 \u1275\u122a\u120a\u12ee\u1295",
+                    "{one:0' '\u123a other:0' '\u123a}",
+                    "{one:00' '\u123a other:00' '\u123a}",
+                    "{one:000' '\u123a other:000' '\u123a}",
+                    "{one:0' '\u121a\u120a\u12ee\u1295 other:0' '\u121a\u120a\u12ee\u1295}",
+                    "{one:00' '\u121a\u120a\u12ee\u1295 other:00' '\u121a\u120a\u12ee\u1295}",
+                    "{one:000' '\u121a\u120a\u12ee\u1295 other:000' '\u121a\u120a\u12ee\u1295}",
+                    "{one:0' '\u1262\u120a\u12ee\u1295 other:0' '\u1262\u120a\u12ee\u1295}",
+                    "{one:00' '\u1262\u120a\u12ee\u1295 other:00' '\u1262\u120a\u12ee\u1295}",
+                    "{one:000' '\u1262\u120a\u12ee\u1295 other:000' '\u1262\u120a\u12ee\u1295}",
+                    "{one:0' '\u1275\u122a\u120a\u12ee\u1295 other:0' '\u1275\u122a\u120a\u12ee\u1295}",
+                    "{one:00' '\u1275\u122a\u120a\u12ee\u1295 other:00' '\u1275\u122a\u120a\u12ee\u1295}",
+                    "{one:000' '\u1275\u122a\u120a\u12ee\u1295 other:000' '\u1275\u122a\u120a\u12ee\u1295}",
                 }
             },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -304,8 +301,9 @@ public class FormatData_am extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "field.zone", "\u12e8\u1230\u12d3\u1275 \u1230\u1245" },
@@ -322,13 +320,14 @@ public class FormatData_am extends ListResourceBundle {
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.hourFormat", "+HHmm;-HHmm" },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u1233\u121d\u1295\u1275" },
             { "buddhist.DateTimePatterns", metaValue_DateTimePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
@@ -343,25 +342,26 @@ public class FormatData_am extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u123a",
-                    "00\u00a0\u123a",
-                    "000\u00a0\u123a",
-                    "0\u00a0\u121c\u1275\u122d",
-                    "00\u00a0\u121c\u1275\u122d",
-                    "000\u121c",
-                    "0\u00a0\u1262",
-                    "00\u00a0\u1262",
-                    "000\u00a0\u1262",
-                    "0\u00a0\u1275",
-                    "00\u00a0\u1275",
-                    "000\u00a0\u1275",
+                    "{one:0\u00a0\u123a other:0\u00a0\u123a}",
+                    "{one:00\u00a0\u123a other:00\u00a0\u123a}",
+                    "{one:000\u00a0\u123a other:000\u00a0\u123a}",
+                    "{one:0\u00a0\u121c\u1275\u122d other:0\u00a0\u121c\u1275\u122d}",
+                    "{one:00\u00a0\u121c\u1275\u122d other:00\u00a0\u121c\u1275\u122d}",
+                    "{one:000\u121c other:000\u121c}",
+                    "{one:0\u00a0\u1262 other:0\u00a0\u1262}",
+                    "{one:00\u00a0\u1262 other:00\u00a0\u1262}",
+                    "{one:000\u00a0\u1262 other:000\u00a0\u1262}",
+                    "{one:0\u00a0\u1275 other:0\u00a0\u1275}",
+                    "{one:00\u00a0\u1275 other:00\u00a0\u1275}",
+                    "{one:000\u00a0\u1275 other:000\u00a0\u1275}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} \u12e8\u1240\u1295 \u1265\u122d\u1203\u1295 \u1230\u12d3\u1275" },
             { "DatePatterns",
                 new String[] {
-                    "EEEE \u1363d MMMM y",
+                    "y MMMM d, EEEE",
                     "d MMMM y",
                     "d MMM y",
                     "dd/MM/y",
@@ -374,6 +374,14 @@ public class FormatData_am extends ListResourceBundle {
             { "field.hour", "\u1230\u12d3\u1275" },
             { "calendarname.buddhist", "\u12e8\u1261\u12f2\u1235\u1275 \u1240\u1295 \u12a0\u1246\u1323\u1320\u122d" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
