@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,7 +71,9 @@ public class LocaleNames_fi extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String metaValue_bax = "bamum";
+        final String metaValue_doi = "dogri";
         final String metaValue_kpe = "kpelle";
+        final String metaValue_mak = "makassar";
         final String metaValue_men = "mende";
         final String metaValue_nqo = "n\u2019ko";
         final Object[][] data = new Object[][] {
@@ -88,10 +90,12 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Zsye", "emoji-symbolit" },
             { "%%NJIVA", "sloveenin resian Gnivan/Njivan alamurre" },
             { "xmf", "mingreli" },
+            { "ccp", "chakma" },
             { "egy", "muinaisegypti" },
             { "raj", "rad\u017eastani" },
             { "Phag", "phags-pa" },
             { "tem", "temne" },
+            { "Medf", "medefaidrin" },
             { "type.nu.sind", "khutabadi-numerot" },
             { "teo", "teso" },
             { "rap", "rapanui" },
@@ -134,6 +138,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "kum", "kumykki" },
             { "BE", "Belgia" },
             { "gmh", "keskiyl\u00e4saksa" },
+            { "Sogo", "muinaissogdialainen" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgaria" },
             { "BH", "Bahrain" },
@@ -156,8 +161,10 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "n\u00e4kyv\u00e4 puhe" },
             { "type.ca.persian", "persialainen kalenteri" },
+            { "%%CREISS", "oksitaanin Croissantin variantti" },
             { "type.nu.hebr", "heprealaiset numerot" },
             { "CA", "Kanada" },
+            { "Kits", "kitaanin pieni merkist\u00f6" },
             { "CC", "Kookossaaret (Keelingsaaret)" },
             { "mzn", "mazandarani" },
             { "CD", "Kongon demokraattinen tasavalta" },
@@ -185,6 +192,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Pauc", "zotuallai" },
             { "vls", "l\u00e4nsiflaami" },
             { "%%RIGIK", "klassinen volap\u00fck" },
+            { "Sogd", "sogdialainen" },
             { "DE", "Saksa" },
             { "goh", "muinaisyl\u00e4saksa" },
             { "ace", "at\u0161eh" },
@@ -295,6 +303,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "zxx", "ei kielellist\u00e4 sis\u00e4lt\u00f6\u00e4" },
             { "Jurc", "d\u017eurt\u0161en" },
             { "tly", "tali\u0161i" },
+            { "%%VIVARAUP", "oksitaanin vivaro-alpiininen variantti" },
             { "pdt", "plautdietsch" },
             { "de_AT", "it\u00e4vallansaksa" },
             { "HK", "Hongkong \u2013 Kiinan e.h.a." },
@@ -392,6 +401,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "LK", "Sri Lanka" },
             { "akk", "akkadi" },
             { "cop", "kopti" },
+            { "Hmnp", "hmongin nyiakeng puachue" },
             { "LR", "Liberia" },
             { "esu", "alaskanjupik" },
             { "LS", "Lesotho" },
@@ -422,7 +432,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "ale", "aleutti" },
             { "Thai", "thailainen" },
             { "type.nu.vaii", "vai-numerot" },
-            { "MK", "Makedonia" },
+            { "MK", "Pohjois-Makedonia" },
             { "type.nu.mathdbl", "matemaattiset kaksoisly\u00f6ntinumerot" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
@@ -434,6 +444,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "MQ", "Martinique" },
             { "MR", "Mauritania" },
             { "MS", "Montserrat" },
+            { "Chrs", "horemzi" },
             { "MT", "Malta" },
             { "cps", "capiznon" },
             { "type.m0.ungegn", "UNGEGN-latinaistus" },
@@ -447,6 +458,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "MZ", "Mosambik" },
             { "Phli", "piirtokirjoituspahlavilainen" },
             { "NA", "Namibia" },
+            { "%%ARANES", "oksitaanin Aranin laakson variantti" },
             { "202", "Saharan etel\u00e4puolinen Afrikka" },
             { "type.ca.hebrew", "juutalainen kalenteri" },
             { "type.co.dictionary", "sanakirjaj\u00e4rjestys" },
@@ -477,10 +489,12 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Mero", "meroiittinen" },
             { "crh", "krimintataari" },
             { "ang", "muinaisenglanti" },
+            { "%%GRMISTR", "oksitaanin Mistral-vaikutteinen ortografia" },
             { "OM", "Oman" },
             { "%%PETR1708", "ven\u00e4j\u00e4n Pietarin siviiliaakkosto 1708" },
             { "anp", "angika" },
             { "crs", "seychellienkreoli" },
+            { "type.nu.hmnp", "hmongin nyiakeng puachue -numerot" },
             { "Xpeo", "muinaispersialainen" },
             { "type.nu.hmng", "pahawh hmong -numerot" },
             { "PA", "Panama" },
@@ -493,6 +507,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "PG", "Papua-Uusi-Guinea" },
             { "PH", "Filippiinit" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "oksitaanin Nizzan variantti" },
             { "PL", "Puola" },
             { "ewo", "ewondo" },
             { "PM", "Saint-Pierre ja Miquelon" },
@@ -521,6 +536,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "tvl", "tuvalu" },
             { "Tavt", "tai viet" },
             { "%%SOTAV", "kapverdenkreolin sotaventolainen murreryhm\u00e4" },
+            { "Maka", metaValue_mak },
             { "001", "maailma" },
             { "002", "Afrikka" },
             { "njo", "ao naga" },
@@ -532,6 +548,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "pnt", "pontoksenkreikka" },
             { "Rjng", "rejang" },
             { "009", "Oseania" },
+            { "Elym", "elymealainen" },
             { "%%SURSILV", "retoromaanin sursilvan-muoto" },
             { "RO", "Romania" },
             { "RS", "Serbia" },
@@ -599,6 +616,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "TC", "Turks- ja Caicossaaret" },
             { "yav", "yangben" },
             { "TD", "T\u0161ad" },
+            { "Qaag", "burmalainen zawgyi-toteutus" },
             { "TF", "Ranskan etel\u00e4iset alueet" },
             { "ase", "amerikkalainen viittomakieli" },
             { "TG", "Togo" },
@@ -646,6 +664,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "US", "Yhdysvallat" },
             { "haw", "havaiji" },
             { "%%1959ACAD", "valkoven\u00e4j\u00e4n virallinen oikeinkirjoitus" },
+            { "%%IVANCHOV", "bulgarian 1899 ortografia" },
             { "type.co.gb2312han", "yksinkertaistettu kiinalainen j\u00e4rjestys GB2312" },
             { "UY", "Uruguay" },
             { "prg", "muinaispreussi" },
@@ -660,6 +679,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Brittil\u00e4iset Neitsytsaaret" },
             { "VI", "Yhdysvaltain Neitsytsaaret" },
+            { "%%LEMOSIN", "oksitaanin Limousin-alueen variantti" },
             { "Soyo", "soyombo-kirjaimisto" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
@@ -686,7 +706,9 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek -numerot" },
             { "wal", "wolaitta" },
             { "was", "washo" },
+            { "XA", "pseudoaksentit" },
             { "war", "waray" },
+            { "XB", "kaksisuuntainen pseudo" },
             { "awa", "awadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "kornin Kernowek-ortografia" },
@@ -731,7 +753,10 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "type.nu.telu", "telugulaiset numerot" },
             { "lou", "louisianankreoli" },
             { "loz", "lozi" },
+            { "%%FONKIRSH", "Kirshenbaumin foneettinen aakkosto" },
             { "Nkgb", "naxi geba" },
+            { "%%ASANTE", "akanin asante-variantti" },
+            { "%%AUVERN", "oksitaanin Auvergnen variantti" },
             { "jmc", "machame" },
             { "hif", "fid\u017einhindi" },
             { "type.nu.hansfin", "yksinkertaistetut kiinalaiset talousnumerot" },
@@ -772,12 +797,14 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "sba", "ngambay" },
             { "Guru", "gurmukhi" },
             { "%%ALUKU", "alukun kreolimurre" },
+            { "type.nu.diak", "dives akuru -numerot" },
             { "lua", "luluanluba" },
             { "%%BISCAYAN", "baskin biskajalaismurre" },
             { "type.nu.tirh", "tirhuta-numerot" },
             { "type.d0.fwidth", "ideogrammin levyinen" },
             { "sbp", "sangu" },
             { "lui", "luise\u00f1o" },
+            { "%%GRITAL", "oksitaanin italialaisvaikutteinen ortografia" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
             { "lun", "lunda" },
@@ -805,6 +832,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "scn", "sisilia" },
             { "aa", "afar" },
             { "ab", "abhaasi" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak-toba" },
             { "ae", "avesta" },
             { "af", "afrikaans" },
@@ -826,7 +854,9 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "sdh", "etel\u00e4kurdi" },
             { "ay", "aimara" },
             { "az", "azeri" },
+            { "Rohg", "rohinjalainen hanifi" },
             { "Khoj", "khojki" },
+            { "%%CISAUP", "oksitaanin luoteisitalialainen variantti" },
             { "%%OSOJS", "sloveenin resian Oseaccon/Osojanen alamurre" },
             { "%%UNIFON", "englannin foneeminen unifon-aakkosto" },
             { "ba", "ba\u0161kiiri" },
@@ -925,10 +955,13 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "type.m0.bgn", "BGN-latinaistus" },
             { "umb", "mbundu" },
             { "fr", "ranska" },
+            { "%%AKUAPEM", "akanin akuapem-murre" },
             { "sid", "sidamo" },
             { "fy", "l\u00e4nsifriisi" },
             { "ga", "iiri" },
+            { "Wcho", "wancholainen" },
             { "gd", "gaeli" },
+            { "Gong", "gondin gunjala" },
             { "gl", "galicia" },
             { "Gonm", "masaram-gondi" },
             { "gn", "guarani" },
@@ -958,6 +991,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "id", "indonesia" },
             { "type.nu.tibt", "tiibetil\u00e4iset numerot" },
             { "ie", "interlingue" },
+            { "%%GASCON", "oksitaanin Gasconyn variantti" },
             { "ig", "igbo" },
             { "ii", "sichuanin-yi" },
             { "frm", "keskiranska" },
@@ -980,7 +1014,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Mlym", "malajalamilainen" },
             { "Sarb", "muinaisetel\u00e4arabialainen" },
             { "Sara", "sarati" },
-            { "doi", "dogri" },
+            { "doi", metaValue_doi },
             { "sly", "selayar" },
             { "type.nu.lepc", "lepchanumerot" },
             { "bkm", "kom" },
@@ -994,9 +1028,9 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "maf", "mafa" },
             { "mai", "maithili" },
             { "smn", "inarinsaame" },
+            { "mak", metaValue_mak },
             { "ka", "georgia" },
             { "bla", "siksika" },
-            { "mak", "makassar" },
             { "wuu", "wu-kiina" },
             { "sms", "koltansaame" },
             { "man", "mandingo" },
@@ -1065,6 +1099,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "nl", "hollanti" },
             { "nn", "norjan nynorsk" },
             { "no", "norja" },
+            { "%%PROVENC", "provensaali" },
             { "nr", "etel\u00e4-ndebele" },
             { "type.nu.modi", "modi-numerot" },
             { "Osge", "osagen aakkosto" },
@@ -1183,6 +1218,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "%%NEDIS", "sloveenin natisonen murre" },
             { "sv", "ruotsi" },
             { "sw", "swahili" },
+            { "type.nu.wcho", "wancholaiset numerot" },
             { "type.nu.hantfin", "perinteiset kiinalaiset talousnumerot" },
             { "ibb", "ibibio" },
             { "iba", "iban" },
@@ -1218,6 +1254,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "%%BISKE", "sloveenin resian San Giorgion/Bilan alamurre" },
             { "150", "Eurooppa" },
             { "151", "It\u00e4-Eurooppa" },
+            { "type.nu.rohg", "hanifilaisen rohingyan numerot" },
             { "type.nu.mathsanb", "matemaattiset p\u00e4\u00e4teviivattomat lihavoidut numerot" },
             { "154", "Pohjois-Eurooppa" },
             { "dzg", "dazaga" },
@@ -1253,12 +1290,14 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "type.nu.mathsans", "matemaattiset p\u00e4\u00e4teviivattomat numerot" },
             { "Osma", "osmanjalainen" },
             { "quc", "k\u02bciche\u02bc" },
+            { "type.nu.gonm", "gondin masaram-numerot" },
             { "qug", "chimborazonyl\u00e4nk\u00f6ket\u0161ua" },
             { "Newa", "newarin newa-tavukirjoitus" },
             { "gaa", "ga" },
             { "wa", "valloni" },
             { "gag", "gagauzi" },
             { "syr", "syyria" },
+            { "type.nu.gong", "gondin gunjala-numerot" },
             { "Grek", "kreikkalainen" },
             { "gan", "gan-kiina" },
             { "kiu", "kirmanjki" },
@@ -1279,10 +1318,12 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "mni", "manipuri" },
             { "Latn", "latinalainen" },
             { "Latg", "latinalainen gaelimuunnelma" },
+            { "Nand", "nandinagari" },
             { "type.nu.hans", "yksinkertaistetut kiinalaiset numerot" },
             { "type.nu.hant", "perinteiset kiinalaiset numerot" },
             { "xh", "xhosa" },
             { "type.nu.romanlow", "roomalaiset piennumerot" },
+            { "Dogr", metaValue_doi },
             { "byn", "bilin" },
             { "%%PAMAKA", "pamakan kreolimurre" },
             { "Lyci", "lyykialainen" },
@@ -1317,6 +1358,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "%%MONOTON", "monotoninen kreikka" },
             { "Geor", "georgialainen" },
             { "Shrd", "\u0161arada" },
+            { "%%LENGADOC", "oksitaanin lengadocian variantti" },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "japanilaiset talousnumerot" },
             { "Cham", "t\u0161amilainen" },
@@ -1331,6 +1373,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Tglg", "tagalogilainen" },
             { "Egyd", "egyptil\u00e4inen demoottinen" },
             { "Egyh", "egyptil\u00e4inen hieraattinen" },
+            { "Yezi", "jesidi" },
             { "%%ITIHASA", "sanskriitin eeppinen muoto" },
             { "Palm", "palmyralainen" },
             { "ebu", "embu" },
@@ -1351,15 +1394,18 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "Sund", "sundalainen" },
             { "vep", "veps\u00e4" },
             { "kpe", metaValue_kpe },
+            { "%%GRCLASS", "oksitaanin klassinen ortografia" },
             { "type.nu.khmr", "khmeril\u00e4iset numerot" },
             { "Tirh", "tirhuta" },
             { "ilo", "iloko" },
             { "%%VALENCIA", "katalaanin valencian murre" },
             { "Cprt", "muinaiskyproslainen" },
+            { "Diak", "dives akuru" },
             { "%%BAKU1926", "yhten\u00e4istetty turkkilainen latinalainen aakkosto" },
             { "%%IJEKAVSK", "serbian ijekavialainen \u00e4\u00e4nt\u00e4mys" },
             { "mua", "mundang" },
             { "type.nu.guru", "gurmukhilaiset numerot" },
+            { "%%BORNHOLM", "Bornholmin murre" },
             { "mul", "useita kieli\u00e4" },
             { "%%PUTER", "retoromaanin puter-muoto" },
             { "cad", "caddo" },
@@ -1376,6 +1422,7 @@ public class LocaleNames_fi extends OpenListResourceBundle {
             { "inh", "inguu\u0161i" },
             { "krj", "kinaray-a" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karjala" },
             { "%%OXENDICT", "englannin Oxfordin sanakirjan oikeinkirjoitus" },
             { "efi", "efik" },
